#ifndef DOCUMENT_CLIENT_H
#define DOCUMENT_CLIENT_H

#include <functional>
#include <memory>
#include <string>
#include <vector>

namespace document {

struct DocumentChunkResponse {
  std::string data;
  void *callbackData;
  int errorCode;
  std::string errorMsg;
};

class ChunkStubManager;
class DocumentChunkClient {

public:
  DocumentChunkClient();
  ~DocumentChunkClient();

  DocumentChunkResponse SyncChunkDocument(const std::vector<std::string> &file_paths,
                                          const std::vector<std::string> &chunker_types,
                                          const std::vector<int32_t> &chunk_sizes);

  using DocumentChunkCallback = std::function<void(const DocumentChunkResponse &response, void *callback_data)>;

  void AsyncChunkDocument(const std::vector<std::string> &file_paths,
                          const std::vector<std::string> &chunker_types,
                          const std::vector<int32_t> &chunk_sizes,
                          void *callback_data,
                          DocumentChunkCallback callback);

private:
  std::unique_ptr<ChunkStubManager> stub_manager_;
};

} // namespace document

#endif // DOCUMENT_CLIENT_H